@@ -1,6 +1,6 @@
 package Ubic;
 {
-  $Ubic::VERSION = '1.50_01';
+  $Ubic::VERSION = '1.57_01';
 }
 
 use strict;
@@ -185,7 +185,9 @@ sub is_enabled($$) {
     my ($name) = validate_pos(@_, $validate_service);
 
     die "Service '$name' not found" unless $self->root_service->has_service($name);
-    return unless -e $self->status_file($name);
+    unless (-e $self->status_file($name)) {
+        return $self->service($name)->auto_start();
+    }
 
     my $status_obj = $self->status_obj_ro($name);
     if ($status_obj->{enabled} or not exists $status_obj->{enabled}) {
@@ -212,11 +214,13 @@ sub cached_status($$) {
     my ($name) = validate_pos(@_, $validate_service);
 
     my $type;
-    unless ($self->is_enabled($name)) {
+    if (not $self->is_enabled($name)) {
         $type = 'disabled';
     }
-    else {
+    elsif (-e $self->status_file($name)) {
         $type = $self->status_obj_ro($name)->{status};
+    } else {
+        $type = 'autostarting';
     }
     return Ubic::Result::Class->new({ type => $type, cached => 1 });
 }
@@ -316,7 +320,7 @@ sub set_cached_status($$$) {
     }
     my $lock = $self->lock($name);
 
-    if ($self->status_obj_ro($name)->{status} eq $status) {
+    if (-e $self->status_file($name) and $self->status_obj_ro($name)->{status} eq $status) {
         # optimization - don't update status if nothing changed
         return;
     }
@@ -474,7 +478,7 @@ sub forked_call {
             POSIX::_exit(0); # don't allow to lock to be released - this process was forked from unknown environment, don't want to run unknown destructors
         }
         catch {
-            # probably tmp_file is not writtable
+            # probably tmp_file is not writable
             warn $_;
             POSIX::_exit(1);
         };
@@ -503,13 +507,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic - polymorphic service manager
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 SYNOPSIS
 
@@ -785,6 +791,8 @@ Ivan Bessarabov <ivan@bessarabov.ru>
 
 Oleg Komarov <komarov@cpan.org>
 
+Andrew Kirkpatrick <ubermonk@gmail.com>
+
 =head1 SEE ALSO
 
 Most Ubic-related links are collected on github wiki: L<http://github.com/berekuk/Ubic/wiki>.
@@ -809,7 +817,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
