@@ -1,6 +1,6 @@
 package Ubic::AccessGuard;
 {
-  $Ubic::AccessGuard::VERSION = '1.50_01';
+  $Ubic::AccessGuard::VERSION = '1.57_01';
 }
 
 use strict;
@@ -68,13 +68,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::AccessGuard - guard for operations with temporarily different effective uid
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 SYNOPSIS
 
@@ -106,7 +108,7 @@ This is considered to be a non-public class. Its interface is subject to change
 
 Construct new access guard object.
 
-User and group will be changed into given C<$credentials>. It will be changed back on guard's desctruction.
+User and group will be changed into given C<$credentials>. It will be changed back on guard's destruction.
 
 =back
 
@@ -116,7 +118,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
