@@ -1,6 +1,6 @@
 package Ubic::Admin::Setup;
 {
-  $Ubic::Admin::Setup::VERSION = '1.50_01';
+  $Ubic::Admin::Setup::VERSION = '1.57_01';
 }
 
 # ABSTRACT: this module handles ubic setup: asks user some questions and configures your system
@@ -14,6 +14,7 @@ use Carp;
 use IPC::Open3;
 use File::Path;
 use File::Which;
+use File::Spec;
 
 use Ubic::AtomicFile;
 use Ubic::Settings;
@@ -276,6 +277,7 @@ sub setup {
     }
 
     my $crontab_env_fix = '';
+    my $crontab_wrap_bash;
     my $ubic_watchdog_full_name = which('ubic-watchdog') or die "ubic-watchdog script not found in your current PATH";
     {
         my @path = split /:/, $ENV{PATH};
@@ -287,12 +289,13 @@ sub setup {
             unless ($HOME) {
                 die "HOME env variable not defined";
             }
-            my $perlbrew_config = "$HOME/perl5/perlbrew/etc/bashrc";
+            my $perlbrew_config = File::Spec->catfile($ENV{PERLBREW_ROOT} || "$HOME/perl5/perlbrew", "etc/bashrc");
             if (not -e $perlbrew_config) {
                 die "Can't find perlbrew config (assumed $perlbrew_config)";
             }
             print_tty "I'll source your perlbrew config in ubic crontab entry to start the watchdog in the correct environment.\n";
             $crontab_env_fix .= "source $perlbrew_config && ";
+            $crontab_wrap_bash = 1;
         }
         elsif (@perls > 1) {
             print_tty "\nYou're using custom perl and it's not from perlbrew.\n";
@@ -381,18 +384,21 @@ sub setup {
             die "crontab -l failed";
         }
 
-        if ($old_crontab =~ /\subic-watchdog\b/) {
-            print "Looks like you already have ubic commands in your crontab.\n";
-        }
-        else {
-            open my $fh, '|-', 'crontab -' or die "Can't run 'crontab -': $!";
-            my $printc = sub {
-                print {$fh} @_ or die "Can't write to pipe: $!";
-            };
-            $printc->($old_crontab."\n");
-            $printc->("* * * * * $crontab_env_fix$ubic_watchdog_full_name ubic.watchdog    >>$log_dir/watchdog.log 2>>$log_dir/watchdog.err.log\n");
-            close $fh or die "Can't close pipe: $!";
+        my @crontab_lines = split /\n/, $old_crontab;
+        @crontab_lines = grep { $_ !~ /\Qubic-watchdog ubic.watchdog\E/ } @crontab_lines;
+
+        open my $fh, '|-', 'crontab -' or die "Can't run 'crontab -': $!";
+        my $printc = sub {
+            print {$fh} @_ or die "Can't write to pipe: $!";
+        };
+
+        my $crontab_command = "$crontab_env_fix$ubic_watchdog_full_name ubic.watchdog";
+        if ($crontab_wrap_bash) {
+            $crontab_command = "bash -c '$crontab_command'";
         }
+        push @crontab_lines, "* * * * * $crontab_command    >>$log_dir/watchdog.log 2>>$log_dir/watchdog.err.log";
+        $printc->("$_\n") for @crontab_lines;
+        close $fh or die "Can't close pipe: $!";
     }
 
     print "Installing $config_file...\n";
@@ -417,13 +423,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Admin::Setup - this module handles ubic setup: asks user some questions and configures your system
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 DESCRPITION
 
@@ -479,7 +487,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
