@@ -1,6 +1,6 @@
 package Ubic::Cmd;
 {
-  $Ubic::Cmd::VERSION = '1.50_01';
+  $Ubic::Cmd::VERSION = '1.57_01';
 }
 
 use strict;
@@ -202,7 +202,7 @@ sub traverse($$$) {
             $indent = $indent + 4;
         }
         for my $subservice ($service->services) {
-            $self->traverse($subservice, $callback, $indent); # FIXME - rememeber result
+            $self->traverse($subservice, $callback, $indent); # FIXME - remember result
         }
     }
     else {
@@ -230,7 +230,7 @@ sub print_status($$;$$) {
         print $name;
 
         # calculating the number of tabs to separate service name from status
-        # status will be aligned whenether possible without sacrificing the real-time properties
+        # status will be aligned whenever possible without sacrificing the real-time properties
         # i.e., we add several tabs to align status with previous lines, but following lines can increase the number of tabs if necessary
         # TODO - there are two possibilities to improve this:
         # 1) look at the further *simple* services and add tabs:
@@ -414,13 +414,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Cmd - ubic methods with pretty printing.
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 SYNOPSIS
 
@@ -439,7 +441,7 @@ This package mostly conforms to C<Ubic> module API (i.e. to LSB init-script API)
 
 =item B<< new($params) >>
 
-All methods of this class can be invoked as class methods, but you can construct your own instance if neccesary (although constructor doesn't have any options by now, so it is useless).
+All methods of this class can be invoked as class methods, but you can construct your own instance if necessary (although constructor doesn't have any options by now, so it is useless).
 
 =back
 
@@ -525,7 +527,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
