@@ -1,6 +1,6 @@
 package Ubic::Credentials::OS::POSIX;
 {
-  $Ubic::Credentials::OS::POSIX::VERSION = '1.50_01';
+  $Ubic::Credentials::OS::POSIX::VERSION = '1.57_01';
 }
 
 use strict;
@@ -178,7 +178,7 @@ sub set_effective {
         $) = "$new_gid 0";
         my ($current_gid) = $) =~ /^(\d+)/;
         if ($current_gid != $new_gid) {
-            die "Failed to change group from $group to $current_group: $!";
+            die "Failed to change group from $current_group to $group: $!";
         }
     }
 
@@ -228,8 +228,8 @@ sub eq {
     if (
         $self->effective_user_id == $other->effective_user_id
         and $self->real_user_id == $other->real_user_id
-        and $self->_groups_equal($self->effective_group_id, $other->effective_group_id)
-        and $self->_groups_equal($self->real_group_id, $other->real_group_id)
+        and $self->_groups_equal(join(" ", $self->effective_group_id), join(" ", $other->effective_group_id))
+        and $self->_groups_equal(join(" ", $self->real_group_id), join(" ", $other->real_group_id))
     ) {
         return 1;
     }
@@ -276,13 +276,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Credentials::OS::POSIX - POSIX-specific credentials implementation
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 METHODS
 
@@ -326,7 +328,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
