@@ -1,6 +1,6 @@
 package Ubic::Daemon;
 {
-  $Ubic::Daemon::VERSION = '1.50_01';
+  $Ubic::Daemon::VERSION = '1.57_01';
 }
 
 use strict;
@@ -209,6 +209,8 @@ sub start_daemon($) {
                 $guard = Ubic::AccessGuard->new($credentials) if $credentials;
                 open STDOUT, ">>", $stdout or die "Can't write to '$stdout': $!";
                 open STDERR, ">>", $stderr or die "Can't write to '$stderr': $!";
+                STDOUT->autoflush(1);
+                STDERR->autoflush(1);
                 if (defined $ubic_log) {
                     open $ubic_fh, ">>", $ubic_log or die "Can't write to '$ubic_log': $!";
                     $ubic_fh->autoflush(1);
@@ -481,13 +483,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Daemon - daemon management utilities
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 SYNOPSIS
 
@@ -655,7 +659,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
