@@ -1,6 +1,6 @@
 package Ubic::Daemon::PidState;
 {
-  $Ubic::Daemon::PidState::VERSION = '1.50_01';
+  $Ubic::Daemon::PidState::VERSION = '1.57_01';
 }
 
 use strict;
@@ -157,13 +157,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Daemon::PidState - internal object representing process info stored on disk
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 INTERFACE SUPPORT
 
@@ -183,7 +185,7 @@ Check if pid dir doesn't exist yet.
 
 =item B<init()>
 
-Create pid dir. After tihs method is called, C<is_empty()> will start to return false value.
+Create pid dir. After this method is called, C<is_empty()> will start to return false value.
 
 =item B<read()>
 
@@ -214,7 +216,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
