@@ -1,6 +1,6 @@
 package Ubic::Result::Class;
 {
-  $Ubic::Result::Class::VERSION = '1.50_01';
+  $Ubic::Result::Class::VERSION = '1.57_01';
 }
 
 use strict;
@@ -47,6 +47,9 @@ sub status {
     elsif (grep { $_ eq $self->{type} } ('down')) {
         return 'down';
     }
+    elsif (grep { $_ eq $self->{type} } ('autostarting')) {
+        return 'autostarting';
+    }
     else {
         return 'broken';
     }
@@ -84,13 +87,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Result::Class - ubic result object
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 SYNOPSIS
 
@@ -126,6 +131,8 @@ Possible statuses:
 
 =item I<down>
 
+=item I<autostarting>
+
 =back
 
 =head1 ACTIONS
@@ -178,7 +185,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
