@@ -1,6 +1,6 @@
 package Ubic::Service;
 {
-  $Ubic::Service::VERSION = '1.50_01';
+  $Ubic::Service::VERSION = '1.57_01';
 }
 
 use strict;
@@ -93,6 +93,10 @@ sub parent_name($;$) {
     }
 }
 
+sub auto_start($) {
+    return 0;
+}
+
 
 1;
 
@@ -100,13 +104,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Service - interface and the base class for any ubic service
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 SYNOPSIS
 
@@ -211,17 +217,17 @@ Services can define custom commands which don't fit into the usual C<start/stop/
 
 =item B<custom_commands()>
 
-Get the list of service's custom commands, if there are any.
+Should return the list of service's custom commands, if there are any.
 
 =item B<do_custom_command($command)>
 
-Execute specified command, if it is supported. Throw an exception otherwise.
+Should execute specified command, if it is supported. Throw an exception otherwise.
 
 =back
 
 =head2 NAME METHODS
 
-These methods should not be overriden by specific service classes.
+These methods should not be overridden by specific service classes.
 They are usually used by the code which loads service (i.e. some kind of L<Ubic::Multiservice>) to associate service with its name.
 
 These methods are just the simple interdependent r/w accessors.
@@ -256,6 +262,12 @@ Get or set a name of the service's parent.
 
 Service's loader (i.e. some kind of L<Ubic::Multiservice>) is responsible for calling this method immediately after a service is constructed, like this: C<< $service->parent_name($self->full_name) >> (check out L<Ubic::Multiservice> sources for more).
 
+=item B<auto_start()>
+
+A boolean value that determines the state of a service if it has never been explicitly enabled or disabled yet. Service is considered initially enabled when auto_start is true.
+
+Default is false, so initial service status is I<off>, and you have to run C<ubic start service_name> to start it.
+
 =back
 
 =head1 FUTURE DIRECTIONS
@@ -279,7 +291,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
