@@ -1,6 +1,6 @@
 package Ubic::Service::SimpleDaemon;
 {
-  $Ubic::Service::SimpleDaemon::VERSION = '1.50_01';
+  $Ubic::Service::SimpleDaemon::VERSION = '1.57_01';
 }
 
 use strict;
@@ -49,6 +49,7 @@ sub new {
         reload_signal => { type => SCALAR, optional => 1 },
         term_timeout => { type => SCALAR, optional => 1, regex => qr/^\d+$/ },
         ulimit => { type => HASHREF, optional => 1 },
+        auto_start => { type => BOOLEAN, default => 0 },
     });
 
     if ($params->{ulimit}) {
@@ -153,6 +154,11 @@ sub reload {
     return result('reloaded', "sent $self->{reload_signal} to $pid, sent HUP to $guardian_pid");
 }
 
+sub auto_start {
+    my $self = shift;
+    return $self->{auto_start};
+}
+
 
 1;
 
@@ -160,13 +166,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Service::SimpleDaemon - service module for daemonizing any binary
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 SYNOPSIS
 
@@ -209,7 +217,7 @@ This is the only mandatory parameter, everything else is optional.
 
 User under which the service will operate.
 
-Default user depends on the configuration chosen at C<ubic-admin setup> stage. See L<Ubic::Settings> for more defails.
+Default user depends on the configuration chosen at C<ubic-admin setup> stage. See L<Ubic::Settings> for more details.
 
 =item I<group>
 
@@ -277,7 +285,7 @@ The signal will be sent both to the daemon, and to the guardian process. Guardia
 
 Change credentials to the given user and group before execing into daemon.
 
-The difference between these options and I<user>/I<group> options is that for I<daemon_*> options, credentials will be set just before before starting the actual daemon. All other service operations will be done using default user. Refer to L<Ubic::Manual::Overview/"Permissions and security"> for the further explanations.
+The difference between these options and I<user>/I<group> options is that for I<daemon_*> options, credentials will be set just before starting the actual daemon. All other service operations will be done using default user. Refer to L<Ubic::Manual::Overview/"Permissions and security"> for the further explanations.
 
 =item I<name>
 
@@ -285,6 +293,10 @@ Service's name.
 
 Name will usually be set by upper-level multiservice. Don't set it unless you know what you're doing.
 
+=item I<auto_start>
+
+Autostart flag is off by default. See L<Ubic::Service> C<auto_start> method for details.
+
 =back
 
 =item B<< pidfile() >>
@@ -303,7 +315,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
