@@ -1,6 +1,6 @@
 package Ubic::Watchdog;
 {
-  $Ubic::Watchdog::VERSION = '1.50_01';
+  $Ubic::Watchdog::VERSION = '1.57_01';
 }
 
 use strict;
@@ -137,12 +137,19 @@ sub check($) {
             return;
         }
 
+        my $cached_status = Ubic->cached_status($name);
         my $status = Ubic->status($name);
         unless ($status->status eq 'running') {
             # following code can throw an exception, so we want to cache invalid status immediately
             Ubic->set_cached_status($name, $status);
 
-            ERROR("$name status is '$status', restarting");
+            if ($cached_status eq "autostarting") {
+                INFO("$name is autostarting");
+            }
+            else {
+                ERROR("$name status is '$status', restarting");
+            }
+
             Ubic->restart($name);
 
             # This is a precaution against services with wrong start/status logic.
@@ -169,13 +176,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Ubic::Watchdog - watchdog code
 
 =head1 VERSION
 
-version 1.50_01
+version 1.57_01
 
 =head1 SYNOPSIS
 
@@ -252,7 +261,7 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Yandex LLC.
+This software is copyright (c) 2014 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
